@@ -26,25 +26,25 @@ L<Lingua::LO::NLP::Romanize> as a factory:
 =cut
 
 my %CONSONANTS = (
-   'ກ'  => 'k', # TODO: split /g/+/k/ here?
-   'ຂ'  => [qw/ kʰ k /],
-   'ຄ'  => [qw/ kʰ k /],
+   'ກ'  => 'k',
+   'ຂ'  => 'kʰ',
+   'ຄ'  => 'kʰ',
    'ງ'  => 'ŋ',
-   'ຈ'  => [qw/ tɕ t /],
-   'ສ'  => [qw/ s t /],
-   'ຊ'  => [qw/ s t /],
+   'ຈ'  => 'tɕ',
+   'ສ'  => 's',
+   'ຊ'  => 's',
    'ຍ'  => 'ɲ',
    'ດ'  => [qw/ d t /],
    'ຕ'  => 't',
-   'ຖ'  => [qw/ tʰ t /],
-   'ທ'  => [qw/ tʰ t /],
+   'ຖ'  => 'tʰ',
+   'ທ'  => 'tʰ',
    'ນ'  => 'n',
    'ບ'  => [qw/ b p /],
    'ປ'  => 'p',
    'ຜ'  => 'pʰ',
-   'ຝ'  => [qw/ f p /],
-   'ພ'  => [qw/ pʰ p /],
-   'ຟ'  => [qw/ f p /],
+   'ຝ'  => 'f',
+   'ພ'  => 'pʰ',
+   'ຟ'  => 'f',
    'ມ'  => 'm',
    'ຢ'  => 'j',
    'ລ'  => 'l',
@@ -53,16 +53,16 @@ my %CONSONANTS = (
    'ຫ'  => 'h',
    'ອ'  => 'ʔ',
    'ຮ'  => 'h',
-   'ຣ'  => 'r',   # TODO l?
+   'ຣ'  => 'r',
    'ໜ'  => 'n',
    'ໝ'  => 'm',
    'ຫຼ'  => 'l',
    'ຫຍ' => 'ɲ',
    'ຫນ' => 'n',
    'ຫມ' => 'm',
-   'ຫຣ' => 'r',   # TODO l?
+   'ຫຣ' => 'r',
    'ຫລ' => 'l',
-   'ຫວ' => 'w', # TODO ʋ?
+   'ຫວ' => 'ʋ',
 );
 
 my %VOWELS = (
@@ -95,17 +95,16 @@ my %VOWELS = (
     'ໂXະ'  => 'oʔ',
     'Xົ'    => 'o',
     'ໂX'   => 'oː',
-    'ໂXຍ'  => 'oːi', # TODO correct?
-    'Xອຍ'  => 'oːi',
+    'ໂXຍ'  => 'oːi',
 
     'ເXາະ' => 'ɔʔ',
     'Xັອ'   => 'ɔ',
     'Xໍ'    => 'ɔː',
     'Xອ'   => 'ɔː',
+    'Xອຍ'  => 'ɔːi',
 
     'ເXິ'   => 'ɤ',
     'ເXີ'   => 'ɤː',
-    'ເXື'   => 'ɯːə', # TODO correct?
 
     'ເXັຍ'  => 'iə',
     'Xັຽ'   => 'iə',
@@ -122,7 +121,6 @@ my %VOWELS = (
 
     'Xົວະ'  => 'uəʔ',
     'Xົວ'   => 'uːə',
-    'Xວ'   => 'uːə',
     'Xວຍ'  => 'uːəi',
 
     'ໄX'   => 'aj',
